@@ -9,6 +9,7 @@ import argparse
 import logging
 import json
 import time
+import datetime
 import os
 import uuid
 from enum import Enum
@@ -25,7 +26,7 @@ from requests import HTTPError
 import graph_notebook
 from graph_notebook.configuration.generate_config import generate_default_config, DEFAULT_CONFIG_LOCATION, AuthModeEnum, \
     Configuration
-from graph_notebook.decorators.decorators import display_exceptions
+from graph_notebook.decorators.decorators import display_exceptions, magic_variables
 from graph_notebook.magics.ml import neptune_ml_magic_handler, generate_neptune_ml_parser
 from graph_notebook.neptune.client import ClientBuilder, Client, VALID_FORMATS, PARALLELISM_OPTIONS, PARALLELISM_HIGH, \
     LOAD_JOB_MODES, MODE_AUTO, FINAL_LOAD_STATUSES, SPARQL_ACTION
@@ -145,6 +146,7 @@ class Graph(Magics):
 
         self.client = builder.build()
 
+    # TODO: find out where we call this, then add local_ns param and variable decorator
     @line_cell_magic
     @display_exceptions
     def graph_notebook_config(self, line='', cell=''):
@@ -183,6 +185,7 @@ class Graph(Magics):
         self._generate_client_from_config(self.graph_notebook_config)
         print(f'set host to {line}')
 
+    @magic_variables
     @cell_magic
     @needs_local_scope
     @display_exceptions
@@ -332,6 +335,7 @@ class Graph(Magics):
         store_to_ns(args.store_to, res, local_ns)
         print(json.dumps(res, indent=2))
 
+    @magic_variables
     @cell_magic
     @needs_local_scope
     @display_exceptions
@@ -340,7 +344,7 @@ class Graph(Magics):
         parser.add_argument('query_mode', nargs='?', default='query',
                             help='query mode (default=query) [query|explain|profile]')
         parser.add_argument('-p', '--path-pattern', default='', help='path pattern')
-        parser.add_argument('-g', '--group-by', default='T.label',
+        parser.add_argument('-g', '--group-by', type=str, default='T.label',
                             help='Property used to group nodes (e.g. code, T.region) default is T.label')
         parser.add_argument('--store-to', type=str, default='', help='store query result to this variable')
         parser.add_argument('--ignore-groups', action='store_true', default=False, help="Ignore all grouping options")
@@ -820,7 +824,12 @@ class Graph(Magics):
                             print(f'Overall Status: {interval_check_response["payload"]["overallStatus"]["status"]}')
                             if interval_check_response["payload"]["overallStatus"]["status"] in FINAL_LOAD_STATUSES:
                                 execution_time = interval_check_response["payload"]["overallStatus"]["totalTimeSpent"]
-                                execution_time_statement = '<1 second' if execution_time == 0 else f'{execution_time} seconds'
+                                if execution_time == 0:
+                                    execution_time_statement = '<1 second'
+                                elif execution_time > 59:
+                                    execution_time_statement = str(datetime.timedelta(seconds=execution_time))
+                                else:
+                                    execution_time_statement = f'{execution_time} seconds'
                                 print('Total execution time: ' + execution_time_statement)
                                 interval_output.close()
                                 print('Done.')
@@ -1067,6 +1076,7 @@ class Graph(Magics):
     def graph_notebook_version(self, line):
         print(graph_notebook.__version__)
 
+    # TODO: find out where we call this, then add local_ns param and variable decorator
     @line_cell_magic
     @display_exceptions
     def graph_notebook_vis_options(self, line='', cell=''):
@@ -1079,6 +1089,7 @@ class Graph(Magics):
             options_dict = json.loads(cell)
             self.graph_notebook_vis_options = vis_options_merge(self.graph_notebook_vis_options, options_dict)
 
+    @magic_variables
     @line_cell_magic
     @display_exceptions
     @needs_local_scope
